package cn.estsh.i3plus.ext.mes.apiservice.serviceimpl.base;

import cn.estsh.i3plus.ext.mes.api.base.IMesDefectService;
import cn.estsh.i3plus.platform.common.exception.ImppExceptionEnum;
import cn.estsh.i3plus.pojo.base.bean.DdlPackBean;
import cn.estsh.i3plus.pojo.base.enumutil.CommonEnumUtil;
import cn.estsh.i3plus.pojo.base.tool.DdlPreparedPack;
import cn.estsh.i3plus.pojo.mes.bean.MesDefect;
import cn.estsh.impp.framework.boot.exception.ImppExceptionBuilder;
import cn.estsh.impp.framework.boot.util.ValidatorBean;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;

@Service
@Slf4j
public class MesDefectService extends BaseMesService<MesDefect> implements IMesDefectService {

    protected void setPackQueryBean(MesDefect bean, DdlPackBean packBean) {
        DdlPreparedPack.getStringLikerPack(bean.getDefectCode(), "defectCode", packBean);
        DdlPreparedPack.getStringLikerPack(bean.getDefectName(), "defectName", packBean);
        DdlPreparedPack.getNumEqualPack(bean.getCategory(), "category", packBean);
    }

    protected void onInsertBean(MesDefect item) {
        // 数据校验
        ValidatorBean.checkNotNull(item.getDefectCode(), "缺陷类型代码不能为空");
        ValidatorBean.checkNotNull(item.getDefectName(), "缺陷类型名称不能为空");

        DdlPackBean packBean = DdlPackBean.getDdlPackBean(item.getOrganizeCode());
        DdlPreparedPack.getStringEqualPack(item.getDefectCode(), "defectCode", packBean);
        boolean flg = baseRDao.isExitByHql(packBean);
        if (flg) {
            throw ImppExceptionBuilder.newInstance()
                    .setSystemID(CommonEnumUtil.SOFT_TYPE.MES.getCode())
                    .setErrorCode(ImppExceptionEnum.VARIFY_EXCEPTION.getCode())
                    .setErrorDetail("【%s】缺陷类型代码已经存在，请检查数据", item.getDefectCode())
                    .build();
        }
    }


    protected void onUpdateBean(MesDefect item) {

        // 数据校验
        ValidatorBean.checkNotNull(item.getDefectCode(), "缺陷类型代码不能为空");
        ValidatorBean.checkNotNull(item.getDefectName(), "缺陷类型名称不能为空");

        DdlPackBean packBean = DdlPackBean.getDdlPackBean(item.getOrganizeCode());
        DdlPreparedPack.getStringEqualPack(item.getDefectCode(), "defectCode", packBean);
        DdlPreparedPack.getNumNOEqualPack(item.getId(), "id", packBean);
        boolean flg = baseRDao.isExitByHql(packBean);
        if (flg) {
            throw ImppExceptionBuilder.newInstance()
                    .setSystemID(CommonEnumUtil.SOFT_TYPE.MES.getCode())
                    .setErrorCode(ImppExceptionEnum.VARIFY_EXCEPTION.getCode())
                    .setErrorDetail("【%s】缺陷类型代码已经存在，请检查数据", item.getDefectCode())
                    .build();
        }
    }

}
